@@ -168,7 +168,7 @@ process_line (char     *line,
 	fdata->link = NULL;
 	fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 	fdata->path = remove_level_from_path (fdata->full_path);
-	fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
+
 	fdata->size = 0;
 	fdata->modified = time (NULL);
 
@@ -180,7 +180,8 @@ process_line (char     *line,
 
 
 static void
-fr_command_unstuff_list (FRCommand *comm)
+fr_command_unstuff_list (FRCommand  *comm,
+			 const char *password)
 {
 	char *arg, *path;
 	char *filename;
@@ -288,6 +289,8 @@ fr_command_unstuff_class_init (FRCommandUnstuffClass *class)
 static void 
 fr_command_unstuff_init (FRCommand *comm)
 {
+	comm->file_type = FR_FILE_TYPE_STUFFIT;
+
 	comm->propCanModify                = FALSE;
 	comm->propAddCanUpdate             = FALSE;
 	comm->propAddCanReplace            = FALSE;
